pyesasky
===============================

ESASky Jupyter widget

Installation
------------

For a development installation (requires npm),

    $ git clone https://github.com/esdc-esac-esa-int/pyesasky.git
    
    $ cd pyesasky
    
    $ sh install.sh
